@@ -7,23 +7,22 @@
 # @Software: PyCharm
 import nonebot
 from nonebot import on_command, logger
-from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent
-from nonebot.adapters.onebot.v11.exception import ActionFailed
-from nonebot.adapters.onebot.v11.permission import GROUP_ADMIN, GROUP_OWNER
+from nonebot.adapters.cqhttp import Bot, GroupMessageEvent
+from nonebot.adapters.cqhttp.exception import ActionFailed
+from nonebot.adapters.cqhttp.permission import GROUP_ADMIN, GROUP_OWNER
 from nonebot.permission import SUPERUSER
-from . import approve
 from .utils import At, banSb, init
-from .group_request_verify import verify
 from . import approve, group_request_verify, group_request, notice, utils, word_analyze, r18_pic_ban, auto_ban
 su = nonebot.get_driver().config.superusers
 
-admin_init =  on_command('群管初始化', priority=1, block=True, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER)
+admin_init = on_command("群管初始化", priority=1, block=True, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER)
 
 
 @admin_init.handle()
-async def _(bot: Bot, event: GroupMessageEvent):
+async def _(bot: Bot,event:GroupMessageEvent):
     await init()
 
+
 ban = on_command('禁', priority=1, block=True, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER)
 
 
@@ -185,7 +184,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     sb = At(event.json())
     gid = event.group_id
     if sb:
-        if len(msg.split()) == len(sb) + 1 and 'all' not in sb:
+        if len(msg.split()) == len(sb) and 'all' not in sb:
             try:
                 for qq in sb:
                     await bot.set_group_special_title(
@@ -214,7 +213,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     sb = At(event.json())
     gid = event.group_id
     if sb:
-        if len(msg.split()) == len(sb) + 1 and 'all' not in sb:
+        if len(msg.split()) == len(sb) and 'all' not in sb:
             try:
                 for qq in sb:
                     await bot.set_group_kick(
@@ -242,7 +241,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     sb = At(event.json())
     gid = event.group_id
     if sb:
-        if len(msg.split()) == len(sb) + 1 and 'all' not in sb:
+        if len(msg.split()) == len(sb) and 'all' not in sb:
             try:
                 for qq in sb:
                     await bot.set_group_kick(
@@ -258,7 +257,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
             await kick_.finish("不能含有@全体成员")
 
 
-set_g_admin = on_command("管理员+", permission=SUPERUSER | GROUP_OWNER, priority=1, block=True)
+set_g_admin = on_command("管理员+", permission=SUPERUSER | GROUP_OWNER, block=True)
 
 
 @set_g_admin.handle()
@@ -273,7 +272,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     logger.info(sb)
     gid = event.group_id
     if sb:
-        if len(msg.split()) == len(sb) + 1 and 'all' not in sb:
+        if len(msg.split()) == len(sb) and 'all' not in sb:
             try:
                 for qq in sb:
                     await bot.set_group_admin(
@@ -290,7 +289,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
             await set_g_admin.finish("指令不正确 或 不能含有@全体成员")
 
 
-unset_g_admin = on_command("管理员-", permission=SUPERUSER | GROUP_OWNER, priority=1, block=True)
+unset_g_admin = on_command("管理员-", permission=SUPERUSER | GROUP_OWNER, block=True)
 
 
 @unset_g_admin.handle()
@@ -305,7 +304,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     logger.info(sb)
     gid = event.group_id
     if sb:
-        if len(msg.split()) == len(sb) + 1 and 'all' not in sb:
+        if len(msg.split()) == len(sb) and 'all' not in sb:
             try:
                 for qq in sb:
                     await bot.set_group_admin(
