@@ -55,9 +55,9 @@ async def g_admin_add(gid: str, qq: int) -> Optional[bool]:
             logger.info(f'{qq}已经是群{gid}的分群管理了')
             return False
         else:
-            gadmins = admins[gid]
-            gadmins.append(qq)
-            admins[gid] = gadmins
+            g_admins = admins[gid]
+            g_admins.append(qq)
+            admins[gid] = g_admins
             async with aiofiles.open(config_group, mode='w') as c:
                 await c.write(str(json.dumps(admins)))
             logger.info(f"群{gid}添加分群管理：{qq}")
