@@ -10,10 +10,10 @@ import json
 import aiofiles
 from pathlib import Path
 from nonebot import logger, on_message, on_command
-from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent
-from nonebot.adapters.onebot.v11.exception import ActionFailed
+from nonebot.adapters.cqhttp import Bot, GroupMessageEvent
+from nonebot.adapters.cqhttp.exception import ActionFailed
 from .utils import init, banSb
-from nonebot.adapters.onebot.v11.permission import GROUP_ADMIN, GROUP_OWNER
+from nonebot.adapters.cqhttp.permission import GROUP_ADMIN, GROUP_OWNER
 from nonebot.permission import SUPERUSER
 
 config_path = Path() / "config"
@@ -40,9 +40,9 @@ async def _(bot: Bot, event: GroupMessageEvent):
     level = (await load_level())
     if str(gid) in level:
         if level[str(gid)] == 'easy':
-            limit_path = limit_word_path
-        else:
             limit_path = limit_word_path_easy
+        else:
+            limit_path = limit_word_path
         f_words = open(limit_path, 'r', encoding='utf-8').read().split('\n')
         for words in f_words:
             if words and words in msg:
