@@ -1,17 +1,16 @@
 # python3
 # -*- coding: utf-8 -*-
-# @Time    : 2022/1/16 22:03
+# @Time    : 2022/1/16 10:20
 # @Author  : yzyyz
 # @Email   :  youzyyz1384@qq.com
 # @File    : group_request.py
 # @Software: PyCharm
 import nonebot
 from nonebot import on_command, on_request, logger
-from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent, GroupRequestEvent, MessageEvent
-from nonebot.adapters.onebot.v11.permission import GROUP_ADMIN, GROUP_OWNER
+from nonebot.adapters.cqhttp import Bot, GroupMessageEvent, GroupRequestEvent, MessageEvent
+from nonebot.adapters.cqhttp.permission import GROUP_ADMIN, GROUP_OWNER, PRIVATE_FRIEND
 from nonebot.permission import SUPERUSER
 from nonebot.typing import T_State
-from nonebot.params import State
 from . import approve
 from .group_request_verify import verify
 import json
@@ -24,6 +23,7 @@ config_json = config_path / "admin.json"
 config_group = config_path / "group_admin.json"
 word_path = config_path / "word_config.txt"
 
+
 # 查看所有审批词条
 super_sp = on_command('所有词条', aliases={"/susp", "/su审批"}, priority=1, block=True, permission=SUPERUSER)
 
@@ -109,11 +109,11 @@ config = on_command('词条+', aliases={'/sp+', '/审批+'}, priority=1, block=T
 
 
 @config.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
     """
     /sp+ 增加本群词条
     """
-    msg = str(state['_prefix']['command_arg'])
+    msg = str(event.get_message())
     sp_write = await approve.write(str(event.group_id), msg)
     if sp_write:
         await config.send(f"群{event.group_id}添加词条：{msg}")
@@ -126,11 +126,11 @@ config_ = on_command('词条-', aliases={'/sp-', '/审批-'}, priority=1, block=
 
 
 @config_.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
     """
     /sp- 删除本群某词条
     """
-    msg = str(state['_prefix']['command_arg'])
+    msg = str(event.get_message())
     sp_delete = await approve.delete(str(event.group_id), msg)
     if sp_delete:
         await config_.send(f"群{event.group_id}删除入群审批词条：{msg}")
