@@ -1,17 +1,17 @@
 # python3
 # -*- coding: utf-8 -*-
-# @Time    : 2022/1/16 22:02
+# @Time    : 2022/1/16 10:13
 # @Author  : yzyyz
 # @Email   :  youzyyz1384@qq.com
 # @File    : notice.py
 # @Software: PyCharm
 
 from nonebot import on_command, logger
-from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent, MessageEvent
-from nonebot.adapters.onebot.v11.permission import GROUP_ADMIN, GROUP_OWNER
+from nonebot.adapters.cqhttp import Bot, GroupMessageEvent, MessageEvent
+from nonebot.adapters.cqhttp.permission import GROUP_ADMIN, GROUP_OWNER
 from nonebot.permission import SUPERUSER
 from nonebot.typing import T_State
-from nonebot.params import State
+
 from . import approve
 from .utils import At
 
@@ -51,7 +51,7 @@ g_admin = on_command('分管+', aliases={"/gad+", "分群管理+"}, priority=1,
 
 
 @g_admin.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
     msg = str(event.get_message())
     sb = At(event.json())
     gid = str(event.group_id)
@@ -63,7 +63,7 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
             else:
                 await g_admin.send(f"用户{qq}已存在")
     else:
-        sb = str(state['_prefix']['command_arg']).split(" ")
+        sb = str(event.get_message()).split(" ")
         for qq in sb:
             g_admin_handle = await approve.g_admin_add(gid, int(qq))
             if g_admin_handle:
@@ -91,7 +91,7 @@ g_admin_ = on_command('分管-', aliases={"/gad-", "分群管理-"}, priority=1,
 
 
 @g_admin_.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
     msg = str(event.get_message())
     sb = At(event.json())
     gid = str(event.group_id)
@@ -105,7 +105,7 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
             elif g_admin_del_handle is None:
                 await g_admin_.send(f"群{gid}未添加过分群管理\n使用/gadmin+ [用户（可@ 可qq）]来添加分群管理")
     else:
-        sb = str(state['_prefix']['command_arg']).split(" ")
+        sb = str(event.get_message()).split(" ")
         for qq in sb:
             g_admin_del_handle = await approve.g_admin_del(gid, int(qq))
             if g_admin_del_handle:
