@@ -6,8 +6,8 @@
 # @File    : r18_pic_ban.py
 # @Software: PyCharm
 from nonebot import logger, on_message
-from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent, MessageEvent
-from nonebot.adapters.onebot.v11.exception import ActionFailed
+from nonebot.adapters.cqhttp import Bot, GroupMessageEvent, MessageEvent
+from nonebot.adapters.cqhttp.exception import ActionFailed
 
 from .utils import pic_ban_cof, banSb
 
